@@ -24,7 +24,7 @@ from os import (
     makedirs,
     path,
     )
-import pipes
+import shlex
 from shutil import rmtree
 from subprocess import (
     CalledProcessError,
@@ -184,7 +184,7 @@ class Cluster:
             #  -k -- socket directory.
             self.execute(
                 "pg_ctl", "start", "-l", self.logfile, "-s", "-w",
-                "-o", "-h '' -F -k %s" % pipes.quote(self.datadir))
+                "-o", "-h '' -F -k %s" % shlex.quote(self.datadir))
 
     def connect(self, database="template1", autocommit=True):
         """Connect to this cluster."""
